@@ -1,9 +1,15 @@
-__version__ = "0.13"
+from __future__ import absolute_import
 import logging
 import os
 import time
 from email.utils import parsedate
+import json
+
 import requests
+import jwt
+
+
+__version__ = "0.15"
 
 
 def make_url(path):
@@ -11,7 +17,7 @@ def make_url(path):
     return "%s%s" % (BASE, path)
 
 
-class APICallException(Exception):
+class APICAllException(Exception):
     pass
 
 
@@ -20,13 +26,13 @@ def if_success(arequest, msg, successcode=200):
         logging.debug("%s worked" % msg)
         return arequest.json()
     else:
-        raise APICallException(
+        raise APICAllException(
             "%s failed. status: %s %s" % (msg, arequest.status_code, arequest.text)
         )
 
 
-class Connect:
-    def __init__(self, client_id=None, client_secret=None):
+class Connect(object):
+    def __init__(self, client_id=None, client_secret=None, jwt_secret=None):
         client_id = client_id or os.environ.get("LIBLYNX_CLIENT_ID")
         if not client_id:
             raise Exception(
@@ -39,6 +45,7 @@ class Connect:
                 "client_secret not specified nor found from ENV LIBLYNX_CLIENT_SECRET"
             )
         self.client_secret = client_secret
+        self.jwt_secret = jwt_secret or os.environ.get("LIBLYNX_JWT_SECRET")
         self.CACHE = {}
 
     def __getattr__(self, attr):
@@ -46,7 +53,7 @@ class Connect:
         if time.time() > expiry:
             getter = "_get_%s" % attr
             logging.debug("%s expired, trying getattr with %s" % (attr, getter))
-            getter = self.__getattribute__(getter)
+            getter = object.__getattribute__(self, getter)
             if getter:
                 value, expiry = getter()
                 logging.debug(
@@ -68,6 +75,9 @@ class Connect:
             return r_json["access_token"], expiry
         logging.error("access_token failed %s %s", r.status_code, r.text)
 
+    def get_jwt_claims(self, token):
+        return jwt.decode(token, self.jwt_secret, algorithms=["HS256"])
+
     def _get_endpoint(self):
         logging.debug("api endpoint expired getting a new one")
         headers = {
@@ -82,7 +92,7 @@ class Connect:
             logging.debug("new api endpoint acquired")
             return api, expires
         else:
-            raise APICallException(
+            raise APICAllException(
                 "api endpoint failed %s %s" % (r.status_code, r.text)
             )
 
@@ -93,13 +103,11 @@ class Connect:
             "Content-Type": "application/json",
         }
         if method == "GET":
-            r = requests.get(href, headers=headers)
-        elif method == "PUT":
-            r = requests.put(href, json=data, headers=headers)
+            r = requests.get(href, headers=headers,)
         elif method == "POST":
-            r = requests.post(href, json=data, headers=headers)
+            r = requests.post(href, data=json.dumps(data), headers=headers,)
         elif method == "DELETE":
-            r = requests.delete(href, headers=headers)
+            r = requests.delete(href, headers=headers,)
             return True
         return if_success(r, msg, successcode)
 
