@@ -35,7 +35,7 @@ def get_ip_address_from_request(request):
             # The client is behind a proxy and the last ip address is
             # the connecting ip address to be used for authentication
             ip_address = x_forwarded_for.split(",")[-1].strip()
-    
+
     return ip_address
 
 
@@ -57,7 +57,7 @@ class LibLynxAuthMiddleware:
 
         identification = self.ll.new_identification(
             self._resolve_host(request),
-            "https://%s%s" % (request.get_host(), src_path),
+            "%s://%s%s" % (request.scheme, request.get_host(), src_path),
             self._request_user_agent(request),
         )
         logger.debug("%s identification: %s" % (self.__class__.__name__, identification))
@@ -109,7 +109,7 @@ class LibLynxAuthMiddleware:
         if products:
             logger.debug("%s products: %s" % (self.__class__.__name__, products))
             request.session[PRODUCTS_PARAM] = list(products.keys())
-        
+
         return True
 
     def _resolve_host(self, request):
