@@ -50,7 +50,9 @@ class LibLynxAuthHTTPMiddleware(BaseHTTPMiddleware):
                         LibLynxUser(llid, ll_accountname),
                     )
             except:
-                logging.debug("Cookie parsing in LibLynxAuthBackend caused exception",)
+                logging.debug(
+                    "Cookie parsing in LibLynxAuthBackend caused exception",
+                )
                 raise AuthenticationError("Cookie Parsing failed")
 
         identification = self.connect.new_identification(
@@ -71,21 +73,19 @@ class LibLynxAuthHTTPMiddleware(BaseHTTPMiddleware):
                     identification["account"]["account_name"],
                 ),
             )
-        return  (
-                AuthCredentials(["authenticated"]),
-                LibLynxUser(
-                    "anon",  # NOTE how we use the Publisher reference and NOT the account id
-                    "Anonymous",
-                ),
-            )
-
-        # Disable WAYF temporarily, and make all access Anonymous if not directly identified
         # elif identification["status"] == "wayf":
         #     logging.debug(
         #         "WAYF needed, asking for %s", identification["_links"]["wayf"]["href"]
         #     )
         #     raise WAYFException(identification["_links"]["wayf"]["href"])
-        return AuthCredentials(), UnauthenticatedUser()
+        # return AuthCredentials(), UnauthenticatedUser()
+        return (
+            AuthCredentials(["authenticated"]),
+            LibLynxUser(
+                "anon",
+                "",
+            ),
+        )
 
     async def __call__(self, scope: Scope, receive: Receive, send: Send) -> None:
         if scope["type"] != "http":
@@ -123,6 +123,16 @@ class LibLynxAuthHTTPMiddleware(BaseHTTPMiddleware):
             response.set_cookie(
                 "llid", cookie, expires=(60 * 60 * 24 * 7)
             )  # expires in one week
+            response.set_cookie(
+                "LIBLYNX_ACCOUNT_ID",
+                request.user.account_id,
+                expires=(60 * 60 * 24 * 7),
+            )
+            response.set_cookie(
+                "LIBLYNX_ACCOUNT", request.user.username, expires=(60 * 60 * 24 * 7)
+            )
+            # expires in one week
+
         return response
 
 
